@@ -50,26 +50,6 @@ func (opts *Options) Clean() {
 	}
 }
 
-func (opts *Options) SetPolicyFlags() {
-	// check that Repo is in the expected format if provided
-	if opts.Repo != "" {
-		// we expect the repo argument to be in the format <OWNER>/<REPO>
-		splitRepo := strings.Split(opts.Repo, "/")
-
-		// if Repo is provided but owner is not, set the OWNER portion of the Repo value
-		// to Owner
-		opts.Owner = splitRepo[0]
-
-		if !isSignerIdentityProvided(opts) {
-			opts.SANRegex = expandToGitHubURL(opts.Tenant, opts.Repo)
-		}
-		return
-	}
-	if !isSignerIdentityProvided(opts) {
-		opts.SANRegex = expandToGitHubURL(opts.Tenant, opts.Owner)
-	}
-}
-
 // AreFlagsValid checks that the provided flag combination is valid
 // and returns an error otherwise
 func (opts *Options) AreFlagsValid() error {
@@ -108,11 +88,6 @@ func (opts *Options) AreFlagsValid() error {
 	return nil
 }
 
-// check if any of the signer identity flags have been provided
-func isSignerIdentityProvided(opts *Options) bool {
-	return opts.SAN != "" || opts.SANRegex != "" || opts.SignerRepo != "" || opts.SignerWorkflow != ""
-}
-
 func isProvidedRepoValid(repo string) bool {
 	// we expect a provided repository argument be in the format <OWNER>/<REPO>
 	splitRepo := strings.Split(repo, "/")
